# FiGTNE

## Description
Encoding a large-scale network into a low-dimensional space is a fundamental step for various network analytic problems, such as node classification, link prediction, community detection, etc. Existing methods focus on learning the network representation from either the static graphs or time-aggregated graphs (e.g., time-evolving graphs). However, many real systems are not static or time-aggregated as the nodes and edges are timestamped and dynamically changing over time.
For examples, in anti-money laundering analysis, cycles formed with time-ordered transactions might be red flags in online transaction networks;  in novelty detection, a star-shaped structure appearing in a short burst might be an underlying hot topic in social networks. Existing embedding models might not be able to well preserve such fine-grained network dynamics due to the incapability of dealing with continuous-time and the negligence of fine-grained interactions.
To bridge this gap, in this paper, we propose a fine-grained temporal network embedding framework named FiGTNE, which aims to learn a comprehensive network representation that preserves the rich and complex network context in the temporal network.
In particular, we start from the notion of fine-grained temporal networks, where the temporal network can be represented as a series of timestamped nodes and edges.
Then, we propose the time-reinforced random walk (TRRW) with a bi-level context sampling strategy to explore the essential structures and temporal contexts in temporal networks. Extensive experimental results on real graphs demonstrate the efficacy of our FiGTNE framework.

## Environment
* Python 3.7
* Tensorflow


## Command to run the code
python demo.py 

## Reference 
@inproceedings{zhou2015tackling,
  title={Towards Fine-Grained Temporal Network Representation via Time-ReinforcedRandom Walk},
  author={Liu Zhining and Zhou, Dawei and Zhu, Yada and Gu, Jinjie and He, Jingrui},
  booktitle={Thirty-Fourth AAAI Conference on Artificial Intelligence},
  year={2020}
}







